[CmdletBinding()]
Param(
  [Parameter(Mandatory=$false,Position=1,HelpMessage="Configuration file")]
   [string]$configurationFile = "Configuration.ps1"
)

If (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole(`
[Security.Principal.WindowsBuiltInRole] "Administrator"))
{
  Write-Error "You do not have Administrator rights to run this script!`nPlease re-run this script as an Administrator!"
  exit
}

Import-Module WebAdministration

function Load-Snapins()
{
  $snapinsToCheck = @("WDeploySnapin3.0")
  $currentSnapins = Get-PSSnapin

  $snapinsToCheck | ForEach-Object `
    {$snapin = $_;
      if(($CurrentSnapins | Where-Object {$_.Name -eq "$snapin"}) -eq $null)
      {
         Write-Host "$snapin snapin not found, loading it"
         Add-PSSnapin $snapin
         Write-Host "$snapin snapin loaded"
      }
    }

  $wdeploySnapin = Get-PSSnapin -Name "WDeploySnapin3.0" -ErrorAction SilentlyContinue
  if (!$wdeploySnapin) 
  {
    Write-Host -foregroundcolor Red "Microsoft Web Deploy snapin was not found and could not be loaded. Microsoft Web Deploy 3.0 is required for this installation, please download Web Deploy from 
    http://www.iis.net/downloads/microsoft/web-deploy and try again. The installation will now exit"
    exit
  }
}

Load-Snapins

. ./$configurationFile

Write-Host -foregroundcolor Green Creating application pool $appPoolName

$ErrorActionPreference = "SilentlyContinue"
$appPoolPath = "IIS:\AppPools\$appPoolName"
$pool = Get-Item $appPoolPath
$ErrorActionPreference = "Continue" 
if ($pool -ne $null) 
{
  Write-Host -Foregroundcolor Yellow Application pool $appPoolName already exists - not making changes to it.
  $poolExists = $true
} else
{
  $poolExists = $false
  $appPool = New-Item $appPoolPath
  $appPool.ManagedRuntimeVersion = "v4.0"
  $appPool.ManagedPipelineMode = "Integrated"
  $appPool.ProcessModel.IdentityType = 2 # Change identity to Network Service
  $appPool | Set-Item
} 

if ($customAppPoolCredentials -and !$poolExists) 
{
  $appPool = Get-Item $appPoolPath
  $appPool.ProcessModel.UserName = $appPoolUser
  $passwordsMatch = $false
  while (!$passwordsMatch)
  {
    $appPoolPasswd = Read-Host -AsSecureString "Please enter password for $appPoolUser"
    $appPoolPasswd2 = Read-Host -AsSecureString "Please verify password for $appPoolUser"
    $appPoolPasswd = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto([System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($appPoolPasswd))
    $appPoolPasswd2 = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto([System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($appPoolPasswd2))
    if ($appPoolPasswd -eq $appPoolPasswd2)
    {
      $passwordsMatch = $true
    } else
    {
      Write-Host -foregroundcolor Yellow "Passwords do not match, please try again"
    }
  }
  $appPool.ProcessModel.Password = $appPoolPasswd
  $appPoolPasswd = $null # Just to be on the safe side
  $appPoolPasswd2 = $null
  $appPool.ProcessModel.IdentityType = 3  # Change identity type to custom account
  $appPool | Set-Item
}

$webApp = Get-Item "IIS:\sites\$webSiteName"
$systemDrive = [system.environment]::getenvironmentvariable("SystemDrive")
$physicalPath = $webApp.PhysicalPath -replace "%SystemDrive%", $systemDrive
$physicalPath = $physicalPath + ($appPath -replace "$webSiteName", "")

Write-Host -foregroundcolor Green Creating new directory $physicalPath for installation
if(!(test-path -path $physicalPath))
{
    New-Item -ItemType Directory -Force -Path $physicalPath
    Write-Host -foregroundcolor Yellow New directory: $physicalPath created.
} else {
     Write-Host -foregroundcolor Yellow $physicalPath already exists - not making change to it.
}
$acl = Get-Acl $physicalPath
Set-Acl $physicalPath $acl

$deployParameters = @{
  ApplicationPath = "$appPath"
}

Write-Host -foregroundcolor Green Deploying QPR Grid Export Service
Restore-WDPackage (Resolve-Path($installPackageName)) -Parameters $deployParameters

Write-Host -foregroundcolor Green Changing $appPath to use application pool: $appPoolName
$appPool = Get-Item $appPoolPath
$sitePath = "IIS:\Sites\$appPath"
Set-ItemProperty -path $sitePath -name applicationPool -value $appPool.Name -Force

Write-Host -foregroundcolor Green "`nOperation completed!`n"
